@@ -2,7 +2,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! assert_cmd = "0.2"
+//! assert_cmd = "0.4"
 //! ```
 //!
 //! ## Example
@@ -37,18 +37,14 @@
 #![warn(missing_docs)]
 
 extern crate escargot;
-#[macro_use]
-extern crate failure;
-#[macro_use]
-extern crate failure_derive;
 extern crate predicates;
 #[macro_use]
 extern crate serde;
 
-mod assert;
-pub use assert::*;
-mod cargo;
-pub use cargo::*;
+pub mod assert;
+pub use assert::Assert;
+pub use assert::OutputAssertExt;
+pub mod cargo;
 mod cmd;
 pub use cmd::*;
 mod stdin;
